@@ -5,7 +5,10 @@ import optparse
 import os
 import sys
 
+import canalweb
+
 from canalweb import vod
+from canalweb import xspf
 
 
 def main(args=None):
@@ -14,7 +17,8 @@ def main(args=None):
         args = sys.argv[1:]
 
     parser = optparse.OptionParser(
-        usage='%prog [options] init | sync <show...> | list <show...>')
+        usage=('%prog [options] init | sync <show...> | list <show...>\n\n' +
+               'Available shows: %s''' % (' '.join(sorted(canalweb.SHOW_BY_NICK)),)))
     parser.add_option('-c', '--cache',
                       action='store', dest='cache', default='.',
                       help='Directory in which to download files')
@@ -53,14 +57,25 @@ def main(args=None):
     if not args:
         parser.error('missing show names')
 
+    try:
+        shows = [canalweb.SHOW_BY_NICK[nick] for nick in args]
+    except KeyError, e:
+        parser.error('unknown show %r' % (e.args,))
+        
     downloader = vod.Downloader(cache)
 
-    for show in args:
-        vods = downloader.get_video_info(show)
-
-        if command == 'list':
-            for video in vods:
+    if command == 'list':
+        for show in shows:
+            videos = downloader.get_video_info(show)
+            for video in videos:
                 print video.date, video.url
-        elif command == 'sync':
-            for video in vods:
-                downloader.fetch_video(video)
+
+    elif command == 'sync':
+        all_videos = []
+        for show in shows:
+            videos = downloader.get_video_info(show)
+            videos.reverse()
+            all_videos.extend(videos)
+        for video in all_videos:
+            downloader.fetch_video(video)
+        open('playlist.xspf', 'w').write(xspf.videos_to_xspf(all_videos))
