@@ -1,3 +1,7 @@
+"""Tests for canalweb.vod."""
+
+# pylint: disable-msg=C0103,W0704,W0212,W0201
+
 import os
 import shutil
 
@@ -6,9 +10,11 @@ from canalweb import vod
 ROOT = os.path.dirname(__file__)
 
 
-class TestVOD(object):
+class TestDownloader(object):
+    """Test the Downloader class."""
 
-    def setup_method(self, m):
+    def setup_method(self, _):
+        """Setup a downloader."""
         self.cache = os.path.join(ROOT, 'test-cache')
         try:
             shutil.rmtree(self.cache)
@@ -19,12 +25,14 @@ class TestVOD(object):
         self.dl = vod.Downloader(self.cache)
 
     def test_content_ids(self):
+        """Check exraction of video IDs."""
         fd = open(os.path.join(ROOT, 'testdata', 'pid1830-c-zapping.html'))
 
         assert [url for url in self.dl.extract_content_ids(fd)] == [
             195190, 195164, 194541, 194196, 193817, 193423, 193128, 192859]
 
     def test_config(self):
+        """Check parsing of the XML file."""
         data = open(os.path.join(ROOT, 'testdata', 'video-config.xml')).read()
         video = self.dl._video_url(data, 'guignoles', 1234)
 
